@@ -8,7 +8,6 @@
 #pragma once
 
 #include "abstractcalendarprovider.h"
-#include "icucalendar_p.h"
 
 /**
  * @short An alternate calendar provider for Chinese calendar system.
@@ -20,10 +19,10 @@ class ChineseCalendarProvider : public AbstractCalendarProvider
     Q_OBJECT
 
 public:
-    explicit ChineseCalendarProvider(QObject *parent, CalendarSystem::System calendarSystem);
+    explicit ChineseCalendarProvider(QObject *parent, CalendarSystem::System calendarSystem, const QDate &startDate, const QDate &endDate);
     ~ChineseCalendarProvider() override;
 
-    CalendarEvents::CalendarEventsPlugin::SubLabel subLabels(const QDate &date) const override;
+    CalendarEvents::CalendarEventsPlugin::SubLabel subLabel(const QDate &date) const override;
 
 private:
     const std::unique_ptr<class ChineseCalendarProviderPrivate> d;
